pub struct DMSCFileSystem { /* private fields */ }Expand description
Public-facing filesystem class.
This struct provides a comprehensive file system abstraction for DMSC, offering safe and reliable file operations with support for atomic writes, directory management, and structured data formats.
Implementations
Sourceimpl DMSCFileSystem
impl DMSCFileSystem
Sourcepub fn new_with_root(project_root: PathBuf) -> Self
pub fn new_with_root(project_root: PathBuf) -> Self
Sourcepub fn new_with_roots(project_root: PathBuf, app_data_root: PathBuf) -> Self
pub fn new_with_roots(project_root: PathBuf, app_data_root: PathBuf) -> Self
Sourcepub fn new_auto_root() -> DMSCResult<Self>
pub fn new_auto_root() -> DMSCResult<Self>
Creates a new file system with the current working directory as the project root.
Returns
A DMSCResult<Self> containing the new DMSCFileSystem instance
Sourcepub fn project_root(&self) -> &Path
pub fn project_root(&self) -> &Path
Sourcepub fn safe_mkdir<P: AsRef<Path>>(&self, path: P) -> DMSCResult<PathBuf>
pub fn safe_mkdir<P: AsRef<Path>>(&self, path: P) -> DMSCResult<PathBuf>
Sourcepub fn ensure_parent_dir<P: AsRef<Path>>(&self, path: P) -> DMSCResult<PathBuf>
pub fn ensure_parent_dir<P: AsRef<Path>>(&self, path: P) -> DMSCResult<PathBuf>
Sourcepub fn atomic_write_text<P: AsRef<Path>>(
&self,
path: P,
text: &str,
) -> DMSCResult<()>
pub fn atomic_write_text<P: AsRef<Path>>( &self, path: P, text: &str, ) -> DMSCResult<()>
Atomically writes text to a file.
This method writes to a temporary file first, then renames it to the target path, ensuring that the write operation is atomic.
Parameters
path: The path to the file to writetext: The text to write to the file
Returns
A DMSCResult<()> indicating success or failure
Sourcepub fn atomic_write_bytes<P: AsRef<Path>>(
&self,
path: P,
data: &[u8],
) -> DMSCResult<()>
pub fn atomic_write_bytes<P: AsRef<Path>>( &self, path: P, data: &[u8], ) -> DMSCResult<()>
Atomically writes bytes to a file.
This method writes to a temporary file first, then renames it to the target path, ensuring that the write operation is atomic.
Parameters
path: The path to the file to writedata: The bytes to write to the file
Returns
A DMSCResult<()> indicating success or failure
Sourcepub fn read_json<P: AsRef<Path>, T: DeserializeOwned>(
&self,
path: P,
) -> DMSCResult<T>
pub fn read_json<P: AsRef<Path>, T: DeserializeOwned>( &self, path: P, ) -> DMSCResult<T>
Sourcepub fn remove_file<P: AsRef<Path>>(&self, path: P) -> DMSCResult<()>
pub fn remove_file<P: AsRef<Path>>(&self, path: P) -> DMSCResult<()>
Sourcepub fn remove_dir_all<P: AsRef<Path>>(&self, path: P) -> DMSCResult<()>
pub fn remove_dir_all<P: AsRef<Path>>(&self, path: P) -> DMSCResult<()>
Sourcepub fn append_text<P: AsRef<Path>>(&self, path: P, text: &str) -> DMSCResult<()>
pub fn append_text<P: AsRef<Path>>(&self, path: P, text: &str) -> DMSCResult<()>
Sourcepub fn write_json<P: AsRef<Path>, T: Serialize>(
&self,
path: P,
value: &T,
) -> DMSCResult<()>
pub fn write_json<P: AsRef<Path>, T: Serialize>( &self, path: P, value: &T, ) -> DMSCResult<()>
Sourcepub fn reports_dir(&self) -> PathBuf
pub fn reports_dir(&self) -> PathBuf
Sourcepub fn observability_dir(&self) -> PathBuf
pub fn observability_dir(&self) -> PathBuf
Sourcepub fn ensure_category_path<S: AsRef<str>, P: AsRef<Path>>(
&self,
category: S,
path_or_name: P,
) -> PathBuf
pub fn ensure_category_path<S: AsRef<str>, P: AsRef<Path>>( &self, category: S, path_or_name: P, ) -> PathBuf